@@ -2,37 +2,32 @@ pompCBuilder <- function (name = NULL, dir = NULL,
                           statenames, paramnames, covarnames, obsnames,
                           rmeasure, dmeasure, step.fn, skeleton,
                           fromEstimationScale, toEstimationScale,
+                          initializer,
                           rprior, dprior, globals,
                           verbose = getOption("verbose",FALSE))
 {
 
-  if (is.null(name)) name <- randomName()
-  if (is.null(dir)) dir <- tempdir()
-
+  if (!is.null(name)) name <- cleanForC(name)
+  id <- randomName(7)
+  
   if (missing(globals)) globals <- character(0)
+  if (is(globals,"Csnippet")) globals <- globals@text
 
-  name <- cleanForC(name)
   statenames <- cleanForC(statenames)
   paramnames <- cleanForC(paramnames)
   covarnames <- cleanForC(covarnames)
   obsnames <- cleanForC(obsnames)
 
-  stem <- file.path(dir,name)
-  if (.Platform$OS.type=="windows") {
-    stem <- gsub("\\","/",stem,fixed=TRUE)
-  }
-  modelfile <- paste0(stem,".c")
-  solib <- paste0(stem,.Platform$dynlib.ext)
-
   if (.Platform$OS.type=="unix") {
     pompheader <- "pomp.h"
   } else {
     pompheader <- system.file("include/pomp.h",package="pomp")
   }
 
-  out <- file(description=modelfile,open="w")
+  csrc <- ""
+  out <- textConnection(object="csrc",open="w",local=TRUE)
 
-  cat(file=out,render(header$file,name=name,pompheader=pompheader))
+  cat(file=out,render(header$file,pompheader=pompheader,id=id))
 
   for (f in utility.fns) {
     cat(file=out,f)
@@ -64,10 +59,18 @@ pompCBuilder <- function (name = NULL, dir = NULL,
   ## list of functions to register
   registry <- c("load_stack_incr","load_stack_decr")
 
+  ## initializer function
+  if (!missing(initializer)) {
+    registry <- c(registry,"initializer")
+    cat(file=out,render(header$initializer))
+    cat(file=out,callable.decl(initializer))
+    cat(file=out,initializer,footer$initializer)
+  }
+
   ## parameter transformation function
   if (!missing(fromEstimationScale)) {
     registry <- c(registry,"par_trans")
-    cat(file=out,render(header$fromEstimationScale,name=name))
+    cat(file=out,render(header$fromEstimationScale))
     cat(file=out,callable.decl(fromEstimationScale))
     cat(file=out,fromEstimationScale,footer$fromEstimationScale)
   }
@@ -75,7 +78,7 @@ pompCBuilder <- function (name = NULL, dir = NULL,
   ## inverse parameter transformation function
   if (!missing(toEstimationScale)) {
     registry <- c(registry,"par_untrans")
-    cat(file=out,render(header$toEstimationScale,name=name))
+    cat(file=out,render(header$toEstimationScale))
     cat(file=out,callable.decl(toEstimationScale))
     cat(file=out,toEstimationScale,footer$toEstimationScale)
   }
@@ -83,19 +86,19 @@ pompCBuilder <- function (name = NULL, dir = NULL,
   ## rmeasure function
   if (!missing(rmeasure)) {
     registry <- c(registry,"rmeasure")
-    cat(file=out,render(header$rmeasure,name=name),rmeasure,footer$rmeasure)
+    cat(file=out,render(header$rmeasure),rmeasure,footer$rmeasure)
   }
 
   ## dmeasure function
   if (!missing(dmeasure)) {
     registry <- c(registry,"dmeasure")
-    cat(file=out,render(header$dmeasure,name=name),dmeasure,footer$dmeasure)
+    cat(file=out,render(header$dmeasure),dmeasure,footer$dmeasure)
   }
 
   ## Euler step function
   if (!missing(step.fn)) {
     registry <- c(registry,"stepfn")
-    cat(file=out,render(header$step.fn,name=name))
+    cat(file=out,render(header$step.fn))
     cat(file=out,callable.decl(step.fn))
     cat(file=out,step.fn,footer$step.fn)
   }
@@ -103,7 +106,7 @@ pompCBuilder <- function (name = NULL, dir = NULL,
   ## skeleton function
   if (!missing(skeleton)) {
     registry <- c(registry,"skelfn")
-    cat(file=out,render(header$skeleton,name=name))
+    cat(file=out,render(header$skeleton))
     cat(file=out,callable.decl(skeleton))
     cat(file=out,skeleton,footer$skeleton)
   }
@@ -111,13 +114,13 @@ pompCBuilder <- function (name = NULL, dir = NULL,
   ## rprior function
   if (!missing(rprior)) {
     registry <- c(registry,"rprior")
-    cat(file=out,render(header$rprior,name=name),rprior,footer$rprior)
+    cat(file=out,render(header$rprior),rprior,footer$rprior)
   }
 
   ## dprior function
   if (!missing(dprior)) {
     registry <- c(registry,"dprior")
-    cat(file=out,render(header$dprior,name=name),dprior,footer$dprior)
+    cat(file=out,render(header$dprior),dprior,footer$dprior)
   }
 
   ## undefine variables
@@ -143,17 +146,57 @@ pompCBuilder <- function (name = NULL, dir = NULL,
   cat(file=out,stackhandling)
 
   ## registration
-  cat(file=out,render(header$registration,name=name))
+  cat(file=out,render(header$registration))
   for (v in registry)
-    cat(file=out,render(registration,name=name,fun=v))
+    cat(file=out,render(registration,fun=v))
   cat(file=out,footer$registration)
 
   close(out)
 
+  csrc <- paste(csrc,collapse="\n")
+
+  if (is.null(name)) 
+    name <- paste0("pomp_",digest(csrc,serialize=FALSE))
+
+  csrc <- render(csrc,name=name)
+
+  pompCompile(fname=name,direc=pompSrcDir(dir),src=csrc,verbose=verbose)
+  
+  invisible(list(name=name,dir=dir,src=csrc))
+}
+
+pompSrcDir <- function (dir) {
+  if (is.null(dir)) {
+    dir <- tempdir()
+  } else {
+    try(
+        rv <- dir.create(dir,recursive=TRUE,showWarnings=FALSE,mode="0700"),
+        silent=TRUE
+        )
+    if (inherits(rv,"try-error"))
+      stop("cannot create cache directory ",sQuote(dir),call.=TRUE)
+  }
+  dir
+}
+
+pompCompile <- function (fname, direc, src, verbose) {
+
+  stem <- file.path(direc,fname)
+  if (.Platform$OS.type=="windows") {
+    stem <- gsub("\\","/",stem,fixed=TRUE)
+  }
+
+  modelfile <- paste0(stem,".c")
+
+  cat(src,file=modelfile)
+  if (verbose) cat("model codes written to",sQuote(modelfile))
+
   cflags <- paste0("PKG_CFLAGS=\"",
                   Sys.getenv("PKG_CFLAGS"),
                   " -I",system.file("include",package="pomp"),"\"")
 
+  solib <- paste0(stem,.Platform$dynlib.ext)
+  if (verbose) cat("compiling",sQuote(solib),"\n")
   rv <- system2(
                 command=R.home("bin/R"),
                 args=c("CMD","SHLIB","-o",solib,modelfile),
@@ -163,10 +206,9 @@ pompCBuilder <- function (name = NULL, dir = NULL,
   if (rv!=0)
     stop("cannot compile shared-object library ",sQuote(solib))
   else if (verbose)
-    cat("model codes written to",sQuote(modelfile),
-        "\nlink to shared-object library",sQuote(solib),"\n")
-
-  invisible(c(name,solib))
+    cat("link to shared-object library",sQuote(solib),"\n")
+  
+  invisible(solib)
 }
 
 callable.decl <- function (code) {
@@ -178,7 +220,7 @@ missing.fun <- function (name) {
   paste0("  error(\"'",name,"' not defined\");")
 }
 
-randomName <- function (stem = "pomp", size = 2) {
+randomName <- function (size = 2, stem = "") {
   paste0(stem,
          paste(
                format(
@@ -199,6 +241,7 @@ cleanForC <- function (text) {
 
 render <- function (template, ...) {
   vars=list(...)
+  if (length(vars)==0) return(template)
   n <- sapply(vars,length)
   if (!all((n==max(n))|(n==1)))
     stop("incommensurate lengths of replacements")
@@ -268,7 +311,7 @@ pompBuilder <- function (data, times, t0, name,
                dir=if (save) getwd() else NULL
                ) -> solib
 
-  name <- solib[1]
+  name <- solib$name
 
   pomp(
        data=data,
@@ -294,7 +337,7 @@ pompBuilder <- function (data, times, t0, name,
        tcovar=tcovar,
        covar=covar,
        ...,
-       .solibfile=list(solib)
+       .solibs=list(solib)
        )
 }
 
@@ -310,12 +353,13 @@ undefine <- list(
                  )
 
 header <- list(
-               file="/* pomp model file: {%name%} */\n\n#include <{%pompheader%}>\n#include <R_ext/Rdynload.h>\n\n",
+               file="/* pomp model file: {%name%} */\n/* {%id%} */\n\n#include <{%pompheader%}>\n#include <R_ext/Rdynload.h>\n\n",
                registration="\nvoid R_init_{%name%} (DllInfo *info)\n{\n",
                rmeasure="\nvoid __pomp_rmeasure (double *__y, const double *__x, const double *__p, const int *__obsindex, const int *__stateindex, const int *__parindex, const int *__covindex, int __ncovars, const double *__covars, double t)\n{\n",
                dmeasure= "\nvoid __pomp_dmeasure (double *__lik, const double *__y, const double *__x, const double *__p, int give_log, const int *__obsindex, const int *__stateindex, const int *__parindex, const int *__covindex, int __ncovars, const double *__covars, double t)\n{\n",
                step.fn="\nvoid __pomp_stepfn (double *__x, const double *__p, const int *__stateindex, const int *__parindex, const int *__covindex, int __covdim, const double *__covars, double t, double dt)\n{\n",
                skeleton="\nvoid __pomp_skelfn (double *__f, const double *__x, const double *__p, const int *__stateindex, const int *__parindex, const int *__covindex, int __ncovars, const double *__covars, double t)\n{\n",
+               initializer="\nvoid __pomp_initializer (double *__x, const double *__p, double t, const int *__stateindex, const int *__parindex, const int *__covindex, const double *__covars)\n{\n",
                fromEstimationScale="\nvoid __pomp_par_trans (double *__pt, const double *__p, const int *__parindex)\n{\n",
                toEstimationScale="\nvoid __pomp_par_untrans (double *__pt, const double *__p, const int *__parindex)\n{\n",
                rprior="\nvoid __pomp_rprior (double *__p, const int *__parindex)\n{\n",
@@ -327,6 +371,7 @@ fnames <- list(
                dmeasure= "__pomp_dmeasure",
                step.fn="__pomp_stepfn",
                skeleton="__pomp_skelfn",
+               initializer="__pomp_initializer",
                fromEstimationScale="__pomp_par_trans",
                toEstimationScale="__pomp_par_untrans",
                rprior="__pomp_rprior",
@@ -347,6 +392,7 @@ footer <- list(
                dmeasure="\n}\n\n",
                step.fn="\n}\n\n",
                skeleton="\n}\n\n",
+               initializer="\n}\n\n",
                fromEstimationScale="\n}\n\n",
                toEstimationScale="\n}\n\n",
                rprior="\n}\n\n",
