@@ -1,12 +1,13 @@
 ## initialize the state variables of the process model
 
-init.state.internal <- function (object, params, t0, ...) {
+init.state.internal <- function (object, params, t0,
+                                 .getnativesymbolinfo = TRUE, ...) {
   if (missing(t0)) t0 <- object@t0
   if (missing(params)) params <- coef(object)
   pompLoad(object)
-  rv <- .Call(do_init_state,object,params,t0)
+  x <- .Call(do_init_state,object,params,t0,.getnativesymbolinfo)
   pompUnload(object)
-  rv
+  x
 }
 
 setMethod('init.state',
