@@ -1,5 +1,7 @@
 trajectory.internal <- function (object, params, times, t0, as.data.frame = FALSE, .getnativesymbolinfo = TRUE, ...) {
 
+  pompLoad(object)
+  
   if (missing(times))
     times <- time(object,t0=FALSE)
   else
@@ -91,6 +93,8 @@ trajectory.internal <- function (object, params, times, t0, as.data.frame = FALS
 
   }
 
+  dimnames(x) <- setNames(dimnames(x),c("variable","rep","time"))
+
   if (as.data.frame) {
     x <- lapply(
                 seq_len(ncol(x)),
@@ -109,6 +113,8 @@ trajectory.internal <- function (object, params, times, t0, as.data.frame = FALS
     x$traj <- factor(x$traj)
   }
 
+  pompUnload(object)
+
   x
 }
 
